/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:47:12-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define LABEL_1_8 7
#define LABEL_1_6 9
#define LABEL_1_9 11
#define LABEL_1_12 13
#define LABEL_1_14 15
#define LABEL_1_15 17
#define TAG_1_16 7
#define LABEL_1_18 19
#define TAG_1_19 8
#define LABEL_1_21 21
#define LABEL_1_22 23
#define TAG_1_23 10
#define LABEL_1_25 25
#define LABEL_1_27 27
#define LABEL_1_28 29
#define TAG_1_29 13
#define LABEL_1_33 31
#define LABEL_1_30 33
#define LABEL_1_31 35
#define TAG_1_32 16
#define LABEL_1_34 37
#define LABEL_1_35 39
#define TAG_1_36 18
#define LABEL_1_45 41
#define LABEL_1_46 43
#define LABEL_1_37 45
#define TAG_1_38 21
#define LABEL_1_47 47
#define LABEL_1_48 49
#define LABEL_1_39 51
#define LABEL_1_49 53
#define LABEL_1_41 55
#define TAG_1_42 26
#define LABEL_1_43 57
#define LABEL_1_53 59
#define LABEL_1_57 61
#define LABEL_1_51 63
#define LABEL_1_56 65
#define LABEL_1_54 67
#define LABEL_1_60 69
#define LABEL_1_62 71
#define LABEL_1_58 73
#define LABEL_1_65 75
#define LABEL_1_61 77
#define LABEL_1_63 79
#define LABEL_1_70 81
#define TAG_1_71 39
#define LABEL_1_73 83
#define LABEL_1_66 85
#define LABEL_1_67 87
#define TAG_1_68 42
#define ENVIRONMENT_LABEL_1_3 147
#define DEBUGGING_LABEL_1_2 146
#define OBJECT_1_11 145
#define OBJECT_1_10 144
#define OBJECT_1_9 143
#define OBJECT_1_8 142
#define OBJECT_1_7 141
#define OBJECT_1_6 140
#define OBJECT_1_5 139
#define OBJECT_1_4 138
#define OBJECT_1_3 137
#define OBJECT_1_2 136
#define OBJECT_1_1 135
#define OBJECT_1_0 134
#define EXECUTE_CACHE_1_74 89
#define EXECUTE_CACHE_1_72 91
#define EXECUTE_CACHE_1_69 93
#define EXECUTE_CACHE_1_64 95
#define EXECUTE_CACHE_1_59 97
#define EXECUTE_CACHE_1_55 99
#define EXECUTE_CACHE_1_52 101
#define EXECUTE_CACHE_1_50 103
#define EXECUTE_CACHE_1_44 105
#define EXECUTE_CACHE_1_40 107
#define EXECUTE_CACHE_1_26 109
#define EXECUTE_CACHE_1_24 111
#define EXECUTE_CACHE_1_20 113
#define EXECUTE_CACHE_1_17 115
#define EXECUTE_CACHE_1_13 117
#define EXECUTE_CACHE_1_11 119
#define EXECUTE_CACHE_1_10 121
#define EXECUTE_CACHE_1_7 123
#define FREE_REFERENCE_1_3 126
#define FREE_REFERENCE_1_2 127
#define FREE_REFERENCE_1_1 128
#define FREE_REFERENCE_1_0 129
#define FREE_ASSIGNMENT_1_2 131
#define FREE_ASSIGNMENT_1_1 132
#define FREE_ASSIGNMENT_1_0 133
#define FREE_REFERENCES_LABEL_1_0 88
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
savres_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd44;
  machine_word Wrd26;
  machine_word Wrd45;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto disk_save_54;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_56;

    case 3:
      current_block = (Rpc - LABEL_1_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_1_9);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_1_12);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_1_14);
      goto continuation_52;

    case 7:
      current_block = (Rpc - LABEL_1_15);
      goto lambda_69;

    case 8:
      current_block = (Rpc - LABEL_1_18);
      goto lambda_70;

    case 9:
      current_block = (Rpc - LABEL_1_21);
      goto continuation_23;

    case 10:
      current_block = (Rpc - LABEL_1_22);
      goto lambda_71;

    case 11:
      current_block = (Rpc - LABEL_1_25);
      goto continuation_24;

    case 12:
      current_block = (Rpc - LABEL_1_27);
      goto continuation_6;

    case 13:
      current_block = (Rpc - LABEL_1_28);
      goto lambda_72;

    case 14:
      current_block = (Rpc - LABEL_1_33);
      goto label_57;

    case 15:
      current_block = (Rpc - LABEL_1_30);
      goto continuation_20;

    case 16:
      current_block = (Rpc - LABEL_1_31);
      goto lambda_73;

    case 17:
      current_block = (Rpc - LABEL_1_34);
      goto continuation_25;

    case 18:
      current_block = (Rpc - LABEL_1_35);
      goto lambda_74;

    case 19:
      current_block = (Rpc - LABEL_1_45);
      goto label_58;

    case 20:
      current_block = (Rpc - LABEL_1_46);
      goto label_59;

    case 21:
      current_block = (Rpc - LABEL_1_37);
      goto lambda_75;

    case 22:
      current_block = (Rpc - LABEL_1_47);
      goto label_60;

    case 23:
      current_block = (Rpc - LABEL_1_48);
      goto label_61;

    case 24:
      current_block = (Rpc - LABEL_1_39);
      goto lambda_33;

    case 25:
      current_block = (Rpc - LABEL_1_49);
      goto label_62;

    case 26:
      current_block = (Rpc - LABEL_1_41);
      goto lambda_76;

    case 27:
      current_block = (Rpc - LABEL_1_43);
      goto continuation_42;

    case 28:
      current_block = (Rpc - LABEL_1_53);
      goto label_64;

    case 29:
      current_block = (Rpc - LABEL_1_57);
      goto label_63;

    case 30:
      current_block = (Rpc - LABEL_1_51);
      goto continuation_7;

    case 31:
      current_block = (Rpc - LABEL_1_56);
      goto continuation_44;

    case 32:
      current_block = (Rpc - LABEL_1_54);
      goto lambda_48;

    case 33:
      current_block = (Rpc - LABEL_1_60);
      goto do_loop_14;

    case 34:
      current_block = (Rpc - LABEL_1_62);
      goto continuation_47;

    case 35:
      current_block = (Rpc - LABEL_1_58);
      goto continuation_45;

    case 36:
      current_block = (Rpc - LABEL_1_65);
      goto label_65;

    case 37:
      current_block = (Rpc - LABEL_1_61);
      goto continuation_10;

    case 38:
      current_block = (Rpc - LABEL_1_63);
      goto continuation_46;

    case 39:
      current_block = (Rpc - LABEL_1_70);
      goto lambda_81;

    case 40:
      current_block = (Rpc - LABEL_1_73);
      goto label_66;

    case 41:
      current_block = (Rpc - LABEL_1_66);
      goto continuation_12;

    case 42:
      current_block = (Rpc - LABEL_1_67);
      goto lambda_80;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disk_save_68)
DEFLABEL (disk_save_54)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_1_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_1_0]))
    goto label_83;
  Wrd7 = Wrd5;

DEFLABEL (label_82)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_1_9);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_1_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_15])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_17]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_1_14);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_83)
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_85;
  Wrd11 = Wrd15;

DEFLABEL (label_84)
  Wrd7 = Wrd11;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_8])), (Wrd12.pObj));

DEFLABEL (label_56)
  (Wrd11.Obj) = Rvl;
  goto label_84;

DEFLABEL (lambda_69)
  CLOSURE_HEADER (LABEL_1_15);

DEFLABEL (lambda_51)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_18])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd18.pObj) [4]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_20]));

DEFLABEL (lambda_70)
  CLOSURE_HEADER (LABEL_1_18);

DEFLABEL (lambda_50)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_22])));
  Rhp += 4;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd20 = Wrd9;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  ((Wrd20.pObj) [2]) = (Wrd23.Obj);
  (Wrd19.Obj) = ((Wrd22.pObj) [3]);
  ((Wrd20.pObj) [3]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd22.pObj) [4]);
  ((Wrd20.pObj) [4]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd20.pObj) [5]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_24]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_1_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_1_25);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_29);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_28])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_71)
  CLOSURE_HEADER (LABEL_1_22);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_1]), 0);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_1_27);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_31])));
  Rhp += 4;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd22 = Wrd9;
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd24.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd24.pObj) [4]);
  ((Wrd22.pObj) [4]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd24.pObj) [5]);
  ((Wrd22.pObj) [5]) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_1_30);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_4]), 1);

DEFLABEL (lambda_72)
  CLOSURE_HEADER (LABEL_1_28);

DEFLABEL (lambda_49)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Wrd15.Obj) = ((Wrd5.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_88;

DEFLABEL (label_87)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_86)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_34]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd23.pObj) = (& (Rhp [-1]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_1_3]);
  (* (Rhp++)) = (Wrd31.Obj);
  (Wrd29.pObj) = (& (Rhp [-1]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd33.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_35])));
  Rhp += 2;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd33.pObj)));
  Wrd36 = Wrd33;
  ((Wrd36.pObj) [2]) = (Wrd24.Obj);
  ((Wrd36.pObj) [3]) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd40.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_37])));
  Rhp += 2;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd40.pObj)));
  Wrd43 = Wrd40;
  ((Wrd43.pObj) [2]) = (Wrd24.Obj);
  ((Wrd43.pObj) [3]) = (Wrd30.Obj);
  (Rsp [2]) = (Wrd39.Obj);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_39]))));
  (Rsp [1]) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_40]));

DEFLABEL (label_88)
  if ((Wrd15.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_87;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_33])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_57)
  goto label_86;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_1_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_44]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_1_43);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 30)
    goto label_92;
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_89;
  Rvl = (current_block [OBJECT_1_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_89)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_56]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_91;
  Wrd16 = Wrd20;

DEFLABEL (label_90)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_50]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_1_56);
  Rvl = (current_block [OBJECT_1_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_91)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_57])), (Wrd17.pObj));

DEFLABEL (label_63)
  (Wrd16.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_92)
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_2]));
  (Wrd34.Obj) = ((Wrd24.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_95;

DEFLABEL (label_94)
  ((Wrd24.pObj) [0]) = (Wrd7.Obj);

DEFLABEL (label_93)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_54]))));
  (Rsp [0]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_55]));

DEFLABEL (label_95)
  if ((Wrd34.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_94;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_53])), (Wrd24.pObj), (Wrd7.Obj));

DEFLABEL (label_64)
  goto label_93;

DEFLABEL (lambda_73)
  CLOSURE_HEADER (LABEL_1_31);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_42);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_41])));
  Rhp += 5;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd22 = Wrd7;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd24.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd24.pObj) [4]);
  ((Wrd22.pObj) [4]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd24.pObj) [5]);
  ((Wrd22.pObj) [5]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd22.pObj) [6]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_1_5]);
  (Rsp [0]) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);

DEFLABEL (lambda_74)
  CLOSURE_HEADER (LABEL_1_35);

DEFLABEL (lambda_32)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_101;

DEFLABEL (label_100)
  Wrd19 = Wrd23;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_98;

DEFLABEL (label_97)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_96)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_98)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_97;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_46])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_59)
  goto label_96;

DEFLABEL (label_101)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_100;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_45])), (Wrd20.pObj));

DEFLABEL (label_58)
  (Wrd19.Obj) = Rvl;
  goto label_99;

DEFLABEL (lambda_75)
  CLOSURE_HEADER (LABEL_1_37);

DEFLABEL (lambda_40)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_107;

DEFLABEL (label_106)
  Wrd19 = Wrd23;

DEFLABEL (label_105)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_1]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_104;

DEFLABEL (label_103)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_102)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_7]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_104)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_103;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_48])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_61)
  goto label_102;

DEFLABEL (label_107)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_106;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_47])), (Wrd20.pObj));

DEFLABEL (label_60)
  (Wrd19.Obj) = Rvl;
  goto label_105;

DEFLABEL (lambda_77)
DEFLABEL (lambda_33)
  INTERRUPT_CHECK (26, LABEL_1_39);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_109;
  Wrd5 = Wrd9;

DEFLABEL (label_108)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_50]));

DEFLABEL (label_109)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_49])), (Wrd6.pObj));

DEFLABEL (label_62)
  (Wrd5.Obj) = Rvl;
  goto label_108;

DEFLABEL (lambda_76)
  CLOSURE_HEADER (LABEL_1_41);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_52]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_1_51);
  goto do_loop_14;

DEFLABEL (lambda_78)
DEFLABEL (lambda_48)
  INTERRUPT_CHECK (26, LABEL_1_54);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_59]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_1_58);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_112;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_62]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_63]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_64]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_1_63);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_72]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_1_62);

DEFLABEL (label_112)
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_111;
  Wrd8 = Wrd12;

DEFLABEL (label_110)
  (Rsp [0]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_50]));

DEFLABEL (label_111)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_65])), (Wrd9.pObj));

DEFLABEL (label_65)
  (Wrd8.Obj) = Rvl;
  goto label_110;

DEFLABEL (do_loop_79)
DEFLABEL (do_loop_14)
  INTERRUPT_CHECK (26, LABEL_1_60);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_8]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_1_61);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_113;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_71);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_70])));
  Rhp += 2;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd15 = Wrd10;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Wrd14.Obj) = ((Wrd17.pObj) [3]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd19.Obj) = ((Wrd17.pObj) [5]);
  (Rsp [0]) = (Wrd19.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_113)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_66]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_68);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_67])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  Wrd27 = Wrd26;
  (Wrd28.Obj) = (Rsp [2]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [4]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_1_9]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_1_10]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_69]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_1_66);
  Rsp = (& (Rsp [1]));
  goto do_loop_14;

DEFLABEL (lambda_81)
  CLOSURE_HEADER (LABEL_1_70);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Wrd15.Obj) = ((Wrd5.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_119;

DEFLABEL (label_118)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_117)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [3]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 30)
    goto label_115;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_114;

DEFLABEL (label_115)
  Rvl = (current_block [OBJECT_1_7]);

DEFLABEL (label_114)
DEFLABEL (label_116)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_119)
  if ((Wrd15.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_118;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_73])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_66)
  goto label_117;

DEFLABEL (lambda_80)
  CLOSURE_HEADER (LABEL_1_67);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_1_11]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_74]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_11 7
#define LABEL_2_13 9
#define LABEL_2_15 11
#define LABEL_2_6 13
#define LABEL_2_8 15
#define LABEL_2_19 17
#define LABEL_2_7 19
#define LABEL_2_10 21
#define LABEL_2_22 23
#define LABEL_2_16 25
#define LABEL_2_23 27
#define LABEL_2_24 29
#define LABEL_2_26 31
#define ENVIRONMENT_LABEL_2_3 59
#define DEBUGGING_LABEL_2_2 58
#define OBJECT_2_4 57
#define OBJECT_2_3 56
#define OBJECT_2_2 55
#define OBJECT_2_1 54
#define OBJECT_2_0 53
#define EXECUTE_CACHE_2_27 33
#define EXECUTE_CACHE_2_25 35
#define EXECUTE_CACHE_2_21 37
#define EXECUTE_CACHE_2_20 39
#define EXECUTE_CACHE_2_18 41
#define EXECUTE_CACHE_2_17 43
#define EXECUTE_CACHE_2_14 45
#define EXECUTE_CACHE_2_12 47
#define EXECUTE_CACHE_2_9 49
#define FREE_REFERENCE_2_0 52
#define FREE_REFERENCES_LABEL_2_0 32
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
savres_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto disk_restore_22;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_19;

    case 2:
      current_block = (Rpc - LABEL_2_11);
      goto label_24;

    case 3:
      current_block = (Rpc - LABEL_2_13);
      goto continuation_10;

    case 4:
      current_block = (Rpc - LABEL_2_15);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_2_6);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_2_8);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_2_19);
      goto continuation_17;

    case 8:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_15;

    case 9:
      current_block = (Rpc - LABEL_2_10);
      goto continuation_20;

    case 10:
      current_block = (Rpc - LABEL_2_22);
      goto lambda_6;

    case 11:
      current_block = (Rpc - LABEL_2_16);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_2_23);
      goto continuation_3;

    case 13:
      current_block = (Rpc - LABEL_2_24);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_2_26);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disk_restore_26)
DEFLABEL (disk_restore_22)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  if ((Wrd11.Obj) == (current_block [OBJECT_2_0]))
    goto label_33;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_2_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  goto lambda_6;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_2_15);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_29;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_16]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_17]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_2_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_14]));

DEFLABEL (label_28)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_2_4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_25]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_2_24);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_6;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_2_13);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_29;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_14]));

DEFLABEL (label_29)
  Rsp = (& (Rsp [3]));

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_18]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_2_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_31;
  Wrd9 = Wrd13;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_12]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_2_10);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 1);

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_11])), (Wrd10.pObj));

DEFLABEL (label_24)
  (Wrd9.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 0);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_2_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;

DEFLABEL (label_34)
  (Wrd8.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_21]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_6);
  goto label_32;

DEFLABEL (label_35)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_2_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_20]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_2_19);
  goto label_34;

DEFLABEL (lambda_27)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_2_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_21]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_23);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_2_26);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  Rvl = (Rsp [0]);
  goto label_36;

DEFLABEL (label_37)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_36)
DEFLABEL (label_38)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define LABEL_3_10 7
#define LABEL_3_8 9
#define LABEL_3_12 11
#define LABEL_3_9 13
#define LABEL_3_15 15
#define LABEL_3_16 17
#define LABEL_3_18 19
#define LABEL_3_20 21
#define LABEL_3_11 23
#define LABEL_3_22 25
#define LABEL_3_23 27
#define LABEL_3_24 29
#define LABEL_3_19 31
#define LABEL_3_17 33
#define LABEL_3_27 35
#define LABEL_3_28 37
#define LABEL_3_29 39
#define LABEL_3_30 41
#define LABEL_3_31 43
#define LABEL_3_32 45
#define LABEL_3_33 47
#define LABEL_3_25 49
#define LABEL_3_26 51
#define LABEL_3_37 53
#define LABEL_3_40 55
#define LABEL_3_34 57
#define LABEL_3_42 59
#define LABEL_3_35 61
#define LABEL_3_39 63
#define LABEL_3_41 65
#define LABEL_3_45 67
#define LABEL_3_43 69
#define LABEL_3_44 71
#define LABEL_3_47 73
#define LABEL_3_46 75
#define LABEL_3_48 77
#define LABEL_3_53 79
#define LABEL_3_52 81
#define LABEL_3_49 83
#define LABEL_3_50 85
#define LABEL_3_56 87
#define LABEL_3_54 89
#define LABEL_3_60 91
#define LABEL_3_58 93
#define LABEL_3_59 95
#define LABEL_3_62 97
#define LABEL_3_65 99
#define LABEL_3_63 101
#define LABEL_3_64 103
#define ENVIRONMENT_LABEL_3_3 156
#define DEBUGGING_LABEL_3_2 155
#define OBJECT_3_19 154
#define OBJECT_3_18 153
#define OBJECT_3_17 152
#define OBJECT_3_16 151
#define OBJECT_3_15 150
#define OBJECT_3_14 149
#define OBJECT_3_13 148
#define OBJECT_3_12 147
#define OBJECT_3_11 146
#define OBJECT_3_10 145
#define OBJECT_3_9 144
#define OBJECT_3_8 143
#define OBJECT_3_7 142
#define OBJECT_3_6 141
#define OBJECT_3_5 140
#define OBJECT_3_4 139
#define OBJECT_3_3 138
#define OBJECT_3_2 137
#define OBJECT_3_1 136
#define OBJECT_3_0 135
#define EXECUTE_CACHE_3_66 105
#define EXECUTE_CACHE_3_61 107
#define EXECUTE_CACHE_3_57 109
#define EXECUTE_CACHE_3_55 111
#define EXECUTE_CACHE_3_51 113
#define EXECUTE_CACHE_3_38 115
#define EXECUTE_CACHE_3_36 117
#define EXECUTE_CACHE_3_21 119
#define EXECUTE_CACHE_3_14 121
#define EXECUTE_CACHE_3_13 123
#define EXECUTE_CACHE_3_7 125
#define EXECUTE_CACHE_3_6 127
#define FREE_REFERENCE_3_4 130
#define FREE_REFERENCE_3_3 131
#define FREE_REFERENCE_3_2 132
#define FREE_REFERENCE_3_1 133
#define FREE_REFERENCE_3_0 134
#define FREE_REFERENCES_LABEL_3_0 104
#define NUMBER_OF_LINKER_SECTIONS_3_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
savres_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd5;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto identify_world_55;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_3_10);
      goto label_57;

    case 3:
      current_block = (Rpc - LABEL_3_8);
      goto continuation_15;

    case 4:
      current_block = (Rpc - LABEL_3_12);
      goto label_58;

    case 5:
      current_block = (Rpc - LABEL_3_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_3_15);
      goto loop_13;

    case 7:
      current_block = (Rpc - LABEL_3_16);
      goto label_59;

    case 8:
      current_block = (Rpc - LABEL_3_18);
      goto label_61;

    case 9:
      current_block = (Rpc - LABEL_3_20);
      goto label_60;

    case 10:
      current_block = (Rpc - LABEL_3_11);
      goto continuation_19;

    case 11:
      current_block = (Rpc - LABEL_3_22);
      goto label_62;

    case 12:
      current_block = (Rpc - LABEL_3_23);
      goto label_63;

    case 13:
      current_block = (Rpc - LABEL_3_24);
      goto label_64;

    case 14:
      current_block = (Rpc - LABEL_3_19);
      goto continuation_7;

    case 15:
      current_block = (Rpc - LABEL_3_17);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_3_27);
      goto label_65;

    case 17:
      current_block = (Rpc - LABEL_3_28);
      goto loop_37;

    case 18:
      current_block = (Rpc - LABEL_3_29);
      goto label_66;

    case 19:
      current_block = (Rpc - LABEL_3_30);
      goto label_67;

    case 20:
      current_block = (Rpc - LABEL_3_31);
      goto label_68;

    case 21:
      current_block = (Rpc - LABEL_3_32);
      goto label_69;

    case 22:
      current_block = (Rpc - LABEL_3_33);
      goto label_70;

    case 23:
      current_block = (Rpc - LABEL_3_25);
      goto continuation_10;

    case 24:
      current_block = (Rpc - LABEL_3_26);
      goto continuation_9;

    case 25:
      current_block = (Rpc - LABEL_3_37);
      goto continuation_40;

    case 26:
      current_block = (Rpc - LABEL_3_40);
      goto label_71;

    case 27:
      current_block = (Rpc - LABEL_3_34);
      goto continuation_30;

    case 28:
      current_block = (Rpc - LABEL_3_42);
      goto label_72;

    case 29:
      current_block = (Rpc - LABEL_3_35);
      goto continuation_34;

    case 30:
      current_block = (Rpc - LABEL_3_39);
      goto continuation_41;

    case 31:
      current_block = (Rpc - LABEL_3_41);
      goto continuation_32;

    case 32:
      current_block = (Rpc - LABEL_3_45);
      goto label_73;

    case 33:
      current_block = (Rpc - LABEL_3_43);
      goto continuation_35;

    case 34:
      current_block = (Rpc - LABEL_3_44);
      goto continuation_42;

    case 35:
      current_block = (Rpc - LABEL_3_47);
      goto continuation_51;

    case 36:
      current_block = (Rpc - LABEL_3_46);
      goto continuation_43;

    case 37:
      current_block = (Rpc - LABEL_3_48);
      goto label_74;

    case 38:
      current_block = (Rpc - LABEL_3_53);
      goto label_75;

    case 39:
      current_block = (Rpc - LABEL_3_52);
      goto continuation_44;

    case 40:
      current_block = (Rpc - LABEL_3_49);
      goto continuation_53;

    case 41:
      current_block = (Rpc - LABEL_3_50);
      goto continuation_52;

    case 42:
      current_block = (Rpc - LABEL_3_56);
      goto label_76;

    case 43:
      current_block = (Rpc - LABEL_3_54);
      goto continuation_45;

    case 44:
      current_block = (Rpc - LABEL_3_60);
      goto label_77;

    case 45:
      current_block = (Rpc - LABEL_3_58);
      goto continuation_47;

    case 46:
      current_block = (Rpc - LABEL_3_59);
      goto continuation_46;

    case 47:
      current_block = (Rpc - LABEL_3_62);
      goto continuation_48;

    case 48:
      current_block = (Rpc - LABEL_3_65);
      goto label_78;

    case 49:
      current_block = (Rpc - LABEL_3_63);
      goto continuation_50;

    case 50:
      current_block = (Rpc - LABEL_3_64);
      goto continuation_49;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (identify_world_80)
DEFLABEL (identify_world_55)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  if ((Wrd8.Obj) == (current_block [OBJECT_3_0]))
    goto label_93;
  (Wrd10.Obj) = (current_block [OBJECT_3_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_3_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_3_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_92;
  Wrd13 = Wrd17;

DEFLABEL (label_91)
  (* (--Rsp)) = (Wrd13.Obj);
  goto loop_13;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_3_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_14]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_3_8);
  (Wrd9.Obj) = (current_block [OBJECT_3_3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd18.Obj) = ((SCHEME_OBJECT) 1);
  if (! ((Wrd18.uLng) == 1))
    goto label_90;
  (Wrd16.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_89)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_3_11);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_88;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_87)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_86;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_85)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd27.uLng) == 30))
    goto label_84;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (Wrd23.Obj) = (MAKE_OBJECT (26, (Wrd26.uLng)));

DEFLABEL (label_83)
  (Rsp [1]) = (Wrd23.Obj);
  goto loop_37;

DEFLABEL (label_84)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_24]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 1);

DEFLABEL (label_64)
  (Wrd23.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_23]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_63)
  (Wrd14.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_22]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_5]), 1);

DEFLABEL (label_62)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_12]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_10])), (Wrd14.pObj));

DEFLABEL (label_57)
  (Wrd13.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_93)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_6]));

DEFLABEL (loop_81)
DEFLABEL (loop_13)
  INTERRUPT_CHECK (26, LABEL_3_15);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_102;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_101)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_96;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_19]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_95;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_94)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_3_19);
  (Wrd10.Obj) = (current_block [OBJECT_3_7]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_95)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_20]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_60)
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_96)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_17]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_100;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_99)
  goto loop_13;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_3_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_3_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_26]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_98;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_97)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_21]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_3_26);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_38]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_3_25);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_98)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_27]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_65)
  (* (--Rsp)) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_18]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_5]), 1);

DEFLABEL (label_61)
  (* (--Rsp)) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_5]), 1);

DEFLABEL (label_59)
  (Wrd5.Obj) = Rvl;
  goto label_101;

DEFLABEL (loop_82)
DEFLABEL (loop_37)
  INTERRUPT_CHECK (26, LABEL_3_28);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_117;
  Rsp = (& (Rsp [2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_3_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_116;
  Wrd9 = Wrd13;

DEFLABEL (label_115)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_3_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_3_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_3_46);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_114;
  Wrd5 = Wrd9;

DEFLABEL (label_113)
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_106;

DEFLABEL (label_105)
  (Wrd22.Obj) = (current_block [OBJECT_3_13]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_3_14]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_3_15]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_3_16]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_49]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_50]))));
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_51]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_3_50);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_104;
  Wrd5 = Wrd9;

DEFLABEL (label_103)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_57]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_3_49);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_3_18]);
  (Rsp [6]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_55]));

DEFLABEL (label_104)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_56])), (Wrd6.pObj));

DEFLABEL (label_76)
  (Wrd5.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_106)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_52]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_3]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_112;
  Wrd16 = Wrd20;

DEFLABEL (label_111)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_3_52);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_3_17]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_3_54);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_59]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_110;
  Wrd12 = Wrd16;

DEFLABEL (label_109)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_61]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_3_59);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_3_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_62]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_3_19]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_3_62);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_63]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_64]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_108;
  Wrd12 = Wrd16;

DEFLABEL (label_107)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_66]));

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_3_64);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_3_63);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_3_47);
  goto label_105;

DEFLABEL (label_108)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_65])), (Wrd13.pObj));

DEFLABEL (label_78)
  (Wrd12.Obj) = Rvl;
  goto label_107;

DEFLABEL (label_110)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_60])), (Wrd13.pObj));

DEFLABEL (label_77)
  (Wrd12.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_53])), (Wrd17.pObj));

DEFLABEL (label_75)
  (Wrd16.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_48])), (Wrd6.pObj));

DEFLABEL (label_74)
  (Wrd5.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_40])), (Wrd10.pObj));

DEFLABEL (label_71)
  (Wrd9.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_117)
  if (! ((Wrd6.uLng) == 1))
    goto label_132;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_131)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd25.uLng) == 30))
    goto label_130;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (Wrd21.Obj) = (MAKE_OBJECT (26, (Wrd24.uLng)));

DEFLABEL (label_129)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd35.uLng) == 26))
    goto label_128;
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd36.Lng) = ((Wrd37.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd36.Lng)))
    goto label_128;
  (Wrd34.Obj) = (LONG_TO_FIXNUM (Wrd36.Lng));

DEFLABEL (label_127)
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 26))
    goto label_126;
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd45.uLng) == 26))
    goto label_126;
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  (Wrd46.Lng) = ((Wrd48.Lng) + (Wrd49.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd46.Lng)))
    goto label_126;
  (Wrd50.Obj) = (LONG_TO_FIXNUM (Wrd46.Lng));
  (* (--Rsp)) = (Wrd50.Obj);

DEFLABEL (label_125)
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 26))
    goto label_124;
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if ((Wrd54.Lng) > 70L)
    goto label_123;

DEFLABEL (label_122)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_34]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_3_10]);
  (* (--Rsp)) = (Wrd61.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_3_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_121;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_120)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_3_41);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_119;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_118)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd14.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_37;

DEFLABEL (label_119)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_45]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_5]), 1);

DEFLABEL (label_73)
  (Wrd5.Obj) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_42]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_72)
  (* (--Rsp)) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_35]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd65.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd65.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_36]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_3_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_3_11]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_3_43);
  (Wrd5.Obj) = (current_block [OBJECT_3_12]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_37;

DEFLABEL (label_124)
  (Wrd67.Obj) = (current_block [OBJECT_3_9]);
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_33]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_INTERFACE_0 (37);

DEFLABEL (label_70)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_122;
  goto label_123;

DEFLABEL (label_126)
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_32]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_69)
  (* (--Rsp)) = Rvl;
  goto label_125;

DEFLABEL (label_128)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_31]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_68)
  (Wrd34.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_130)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_30]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 1);

DEFLABEL (label_67)
  (Wrd21.Obj) = Rvl;
  goto label_129;

DEFLABEL (label_132)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_29]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_4]), 1);

DEFLABEL (label_66)
  (Wrd12.Obj) = Rvl;
  goto label_131;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5 3
#define LABEL_6 5
#define LABEL_7 7
#define ENVIRONMENT_LABEL_3 16
#define DEBUGGING_LABEL_2 15
#define PURIFICATION_ROOT 14
#define OBJECT_2 13
#define OBJECT_1 12
#define OBJECT_0 11
#define GLOBAL_EXECUTE_CACHE_4 9
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
savres_so_84d6ca69f64db586 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_5)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_4)
  {
    static const short sections [] =
      {
	0,
	2,
	2,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 3)
      goto label_3;
    blocks = (current_block [OBJECT_2]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_3)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

static const struct liarc_code_S arr_decl_savres_so_84d6ca69f64db586 [3] =
  {
    { "savres_so_code_1", 43, savres_so_code_1 },
    { "savres_so_code_2", 15, savres_so_code_2 },
    { "savres_so_code_3", 51, savres_so_code_3 }
  };

int
decl_savres_so_84d6ca69f64db586 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_savres_so_84d6ca69f64db586);
  return (0);
}

DECLARE_COMPILED_CODE ("savres.so", 3, decl_savres_so_84d6ca69f64db586, savres_so_84d6ca69f64db586)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_savres_so_data_84d6ca69f64db586 [2497] =
  "\xa2\x01\x0b\xae\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0d\x0c"
  "\xc2\x1d\xc2\x02\xc1\x07\xc1\xc0\x1d\x0d\xb9\x0d\xba\x0d\xbb\x25"
  "\xb3\xb2\x0d\x0d\x24\x28\x0d\xbc\x28\x0d\x28\x0d\xbd\x28\x0d\x28"
  "\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\xbe\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\xbf\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x82\x88\x0c\xc1\x0c"
  "\xc0\x1d\x0d\x24\x28\x0d\x28\xb6\x28\x0d\x28\x0d\x28\xb5\x28\x1b"
  "\x28\xb4\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\x0c\x0c\x0c"
  "\x07\x81\x0c\x0c\x80\x0c\x0c\x02\x0c\x08\xc1\xc1\xc1\x0c\x0c\x0c"
  "\x0c\x0c\x08\x8b\xb7\x1d\x0d\x0d\xbe\xb1\xb3\x0d\x24\x28\x0d\x28"
  "\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbd"
  "\x9a\xbc\x88\xb4\x0c\xb5\x2a\x1b\x2a\x1b\x2a\x06\x06\x0c\x9e\xb6"
  "\xb7\x0d\x0d\xb2\xb1\xb3\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x02\x78\x2f\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e\x6d"
  "\x69\x74\x2e\x65\x64\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61\x63"
  "\x2f\x70\x72\x6f\x6a\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d\x65"
  "\x2f\x76\x37\x2f\x64\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68\x6f"
  "\x74\x2e\x70\x6b\x67\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x6d"
  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30\x37"
  "\x30\x39\x30\x39\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65"
  "\x2f\x73\x61\x76\x72\x65\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
  "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
  "\x02\x12\x44\x69\x73\x6b\x20\x73\x61\x76\x65\x20\x66\x61\x69\x6c"
  "\x65\x64\x3a\x06\x72\x65\x74\x72\x79\x0b\x54\x72\x79\x20\x61\x67"
  "\x61\x69\x6e\x2e\x0a\x64\x75\x6d\x70\x2d\x62\x61\x6e\x64\x02\x14"
  "\x77\x69\x74\x68\x2d\x69\x6e\x74\x65\x72\x72\x75\x70\x74\x2d\x6d"
  "\x61\x73\x6b\x08\x1a\x73\x65\x74\x2d\x66\x69\x78\x65\x64\x2d\x6f"
  "\x62\x6a\x65\x63\x74\x73\x2d\x76\x65\x63\x74\x6f\x72\x21\x1f\x63"
  "\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x63\x75\x72\x72\x65\x6e\x74"
  "\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x19\x67\x65"
  "\x74\x2d\x66\x69\x78\x65\x64\x2d\x6f\x62\x6a\x65\x63\x74\x73\x2d"
  "\x76\x65\x63\x74\x6f\x72\x08\x11\x74\x69\x6d\x65\x2d\x77\x6f\x72"
  "\x6c\x64\x2d\x73\x61\x76\x65\x64\x19\x2a\x77\x69\x74\x68\x69\x6e"
  "\x2d\x72\x65\x73\x74\x6f\x72\x65\x2d\x77\x69\x6e\x64\x6f\x77\x3f"
  "\x2a\x09\x77\x6f\x72\x6c\x64\x2d\x69\x64\x04\x14\x65\x76\x65\x6e"
  "\x74\x3a\x61\x66\x74\x65\x72\x2d\x72\x65\x73\x74\x6f\x72\x65\x14"
  "\x65\x76\x65\x6e\x74\x3a\x61\x66\x74\x65\x72\x2d\x72\x65\x73\x74"
  "\x61\x72\x74\x05\x03\x10\x6d\x65\x72\x67\x65\x2d\x70\x61\x74\x68"
  "\x6e\x61\x6d\x65\x73\x02\x13\x6c\x6f\x63\x61\x6c\x2d\x64\x65\x63"
  "\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x03\x0d\x2d\x3e\x6e\x61\x6d"
  "\x65\x73\x74\x72\x69\x6e\x67\x02\x09\x67\x63\x2d\x63\x6c\x65\x61"
  "\x6e\x03\x13\x77\x69\x74\x68\x6f\x75\x74\x2d\x69\x6e\x74\x65\x72"
  "\x72\x75\x70\x74\x73\x03\x1f\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68"
  "\x2d\x63\x75\x72\x72\x65\x6e\x74\x2d\x63\x6f\x6e\x74\x69\x6e\x75"
  "\x61\x74\x69\x6f\x6e\x03\x1e\x77\x69\x74\x68\x2d\x61\x62\x73\x6f"
  "\x6c\x75\x74\x65\x6c\x79\x2d\x6e\x6f\x2d\x69\x6e\x74\x65\x72\x72"
  "\x75\x70\x74\x73\x02\x1a\x72\x65\x2d\x72\x65\x61\x64\x2d\x6d\x69"
  "\x63\x72\x6f\x63\x6f\x64\x65\x2d\x74\x61\x62\x6c\x65\x73\x21\x05"
  "\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62"
  "\x69\x6e\x64\x02\x13\x73\x74\x61\x72\x74\x2d\x74\x68\x72\x65\x61"
  "\x64\x2d\x74\x69\x6d\x65\x72\x03\x1a\x65\x76\x65\x6e\x74\x2d\x64"
  "\x69\x73\x74\x72\x69\x62\x75\x74\x6f\x72\x2f\x69\x6e\x76\x6f\x6b"
  "\x65\x21\x02\x08\x67\x63\x2d\x66\x6c\x69\x70\x03\x11\x61\x62\x6f"
  "\x72\x74\x2d\x3e\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x03\x11\x63"
  "\x6d\x64\x6c\x2f\x62\x61\x74\x63\x68\x2d\x6d\x6f\x64\x65\x3f\x03"
  "\x0a\x63\x6d\x64\x6c\x2f\x70\x6f\x72\x74\x05\x14\x77\x69\x74\x68"
  "\x2d\x73\x69\x6d\x70\x6c\x65\x2d\x72\x65\x73\x74\x61\x72\x74\x03"
  "\x0f\x69\x64\x65\x6e\x74\x69\x66\x79\x2d\x77\x6f\x72\x6c\x64\x04"
  "\x06\x65\x72\x72\x6f\x72\x09\x13\x2e\x58\x81\x83\x02\x2d\x56\x81"
  "\x87\x02\x2c\x54\x81\x83\x02\x2b\x52\x81\x83\x02\x2a\x50\x81\x85"
  "\x02\x29\x4e\x81\x85\x02\x28\x4c\x81\x83\x02\x27\x4a\x81\x83\x02"
  "\x26\x48\x81\x83\x02\x25\x46\x81\x85\x02\x24\x44\x83\x04\x23\x42"
  "\x81\x83\x02\x22\x40\x81\x85\x02\x21\x3e\x81\x85\x02\x20\x3c\x81"
  "\x83\x02\x1f\x3a\x81\x83\x02\x1e\x38\x81\x85\x02\x1d\x36\x81\x81"
  "\x02\x1c\x34\x82\x02\x1b\x32\x81\x87\x02\x1a\x30\x81\x85\x02\x19"
  "\x2e\x81\x83\x02\x18\x2c\x81\x87\x02\x17\x2a\x81\x85\x02\x16\x28"
  "\x81\x83\x02\x15\x26\x81\x83\x02\x14\x24\x81\x85\x02\x13\x22\x81"
  "\x85\x02\x12\x20\x81\x83\x02\x11\x1e\x81\x83\x02\x10\x1c\x81\x83"
  "\x02\x0f\x1a\x81\x85\x02\x0e\x18\x81\x83\x02\x0d\x16\x81\x85\x02"
  "\x0c\x14\x81\x85\x02\x0b\x12\x81\x83\x02\x0a\x10\x81\x87\x02\x09"
  "\x0e\x81\x87\x02\x08\x0c\x81\x87\x02\x07\x0a\x81\x87\x02\x06\x08"
  "\x81\x87\x02\x05\x06\x81\x85\x02\x04\x04\x84\x04\x57\x94\x01\x0a"
  "\x02\x04\x63\x6f\x6d\x0a\x6c\x6f\x61\x64\x2d\x62\x61\x6e\x64\x1f"
  "\x6e\x6f\x20\x64\x65\x66\x61\x75\x6c\x74\x20\x62\x61\x6e\x64\x20"
  "\x6e\x61\x6d\x65\x20\x61\x76\x61\x69\x6c\x61\x62\x6c\x65\x11\x72"
  "\x65\x6c\x6f\x61\x64\x2d\x62\x61\x6e\x64\x2d\x6e\x61\x6d\x65\x08"
  "\x12\x65\x76\x65\x6e\x74\x3a\x62\x65\x66\x6f\x72\x65\x2d\x65\x78"
  "\x69\x74\x02\x03\x0b\x2d\x3e\x70\x61\x74\x68\x6e\x61\x6d\x65\x03"
  "\x03\x18\x73\x79\x73\x74\x65\x6d\x2d\x6c\x69\x62\x72\x61\x72\x79"
  "\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x03\x0e\x70\x61\x74\x68\x6e"
  "\x61\x6d\x65\x2d\x74\x79\x70\x65\x03\x03\x09\x03\x04\x12\x70\x61"
  "\x74\x68\x6e\x61\x6d\x65\x2d\x6e\x65\x77\x2d\x74\x79\x70\x65\x03"
  "\x0d\x66\x69\x6c\x65\x2d\x65\x78\x69\x73\x74\x73\x3f\x0a\x3d\x20"
  "\x81\x83\x02\x3c\x1e\x81\x85\x02\x3b\x1c\x81\x83\x02\x3a\x1a\x81"
  "\x85\x02\x39\x18\x81\x83\x02\x38\x16\x81\x83\x02\x37\x14\x81\x87"
  "\x02\x36\x12\x81\x89\x02\x35\x10\x81\x87\x02\x34\x0e\x81\x85\x02"
  "\x33\x0c\x81\x83\x02\x32\x0a\x81\x83\x02\x31\x08\x81\x85\x02\x30"
  "\x06\x81\x83\x02\x2f\x04\x83\x02\x1f\x3c\x09\x02\x05\x20\x61\x74"
  "\x20\x01\x0b\x20\x73\x61\x76\x65\x64\x20\x6f\x6e\x20\x03\x20\x20"
  "\x05\x20\x7c\x7c\x20\x04\x20\x20\x20\x02\x20\x47\x02\x2c\x0e\x73"
  "\x74\x72\x69\x6e\x67\x2d\x6c\x65\x6e\x67\x74\x68\x04\x63\x64\x72"
  "\x04\x63\x61\x72\x0e\x43\x6f\x70\x79\x72\x69\x67\x68\x74\x20\x28"
  "\x43\x29\x0e\x4d\x61\x73\x73\x61\x63\x68\x75\x73\x65\x74\x74\x73"
  "\x0a\x49\x6e\x73\x74\x69\x74\x75\x74\x65\x03\x6f\x66\x0b\x54\x65"
  "\x63\x68\x6e\x6f\x6c\x6f\x67\x79\x08\x10\x63\x6f\x70\x79\x72\x69"
  "\x67\x68\x74\x2d\x79\x65\x61\x72\x73\x12\x6c\x69\x63\x65\x6e\x73"
  "\x65\x2d\x73\x74\x61\x74\x65\x6d\x65\x6e\x74\x24\x67\x65\x74\x2d"
  "\x73\x75\x62\x73\x79\x73\x74\x65\x6d\x2d\x69\x64\x65\x6e\x74\x69"
  "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x73\x74\x72\x69\x6e\x67\x06"
  "\x02\x14\x63\x75\x72\x72\x65\x6e\x74\x2d\x6f\x75\x74\x70\x75\x74"
  "\x2d\x70\x6f\x72\x74\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65\x65"
  "\x2d\x6f\x75\x74\x70\x75\x74\x2d\x70\x6f\x72\x74\x04\x0d\x77\x72"
  "\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x04\x07\x61\x70\x70\x65"
  "\x6e\x64\x03\x0f\x6e\x75\x6d\x62\x65\x72\x2d\x3e\x73\x74\x72\x69"
  "\x6e\x67\x03\x08\x6e\x65\x77\x6c\x69\x6e\x65\x04\x0e\x73\x74\x72"
  "\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x02\x14\x67\x65\x74\x2d"
  "\x73\x75\x62\x73\x79\x73\x74\x65\x6d\x2d\x6e\x61\x6d\x65\x73\x09"
  "\x19\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x73\x2d\x69"
  "\x6e\x2d\x63\x6f\x6c\x75\x6d\x6e\x73\x04\x04\x6d\x61\x70\x03\x19"
  "\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f\x64\x61\x74"
  "\x65\x2d\x73\x74\x72\x69\x6e\x67\x03\x19\x64\x65\x63\x6f\x64\x65"
  "\x64\x2d\x74\x69\x6d\x65\x2f\x74\x69\x6d\x65\x2d\x73\x74\x72\x69"
  "\x6e\x67\x0d\x70\x68\x81\x87\x02\x6f\x66\x81\x83\x02\x6e\x64\x81"
  "\x89\x02\x6d\x62\x81\x83\x02\x6c\x60\x81\x87\x02\x6b\x5e\x81\x83"
  "\x02\x6a\x5c\x81\x89\x02\x69\x5a\x81\x83\x02\x68\x58\x81\x91\x02"
  "\x67\x56\x81\x8f\x02\x66\x54\x81\x8d\x02\x65\x52\x81\x83\x02\x64"
  "\x50\x81\x87\x02\x63\x4e\x81\x83\x02\x62\x4c\x81\x83\x02\x61\x4a"
  "\x81\x83\x02\x60\x48\x81\x83\x02\x5f\x46\x81\x89\x02\x5e\x44\x81"
  "\x89\x02\x5d\x42\x81\x89\x02\x5c\x40\x81\x83\x02\x5b\x3e\x81\x89"
  "\x02\x5a\x3c\x81\x8d\x02\x59\x3a\x81\x89\x02\x58\x38\x81\x87\x02"
  "\x57\x36\x81\x83\x02\x56\x34\x81\x89\x02\x55\x32\x81\x85\x02\x54"
  "\x30\x81\x89\x02\x53\x2e\x81\x87\x02\x52\x2c\x81\x87\x02\x51\x2a"
  "\x81\x87\x02\x50\x28\x81\x87\x02\x4f\x26\x81\x87\x02\x4e\x24\x81"
  "\x8b\x02\x4d\x22\x81\x83\x02\x4c\x20\x81\x83\x02\x4b\x1e\x81\x87"
  "\x02\x4a\x1c\x81\x87\x02\x49\x1a\x81\x85\x02\x48\x18\x81\x85\x02"
  "\x47\x16\x81\x85\x02\x46\x14\x81\x85\x02\x45\x12\x81\x83\x02\x44"
  "\x10\x81\x83\x02\x43\x0e\x81\x87\x02\x42\x0c\x81\x89\x02\x41\x0a"
  "\x81\x83\x02\x40\x08\x81\x89\x02\x3f\x06\x81\x83\x02\x3e\x04\x83"
  "\x02\x67\x9d\x01\x97\x01\x54\x68\x69\x73\x20\x69\x73\x20\x66\x72"
  "\x65\x65\x20\x73\x6f\x66\x74\x77\x61\x72\x65\x3b\x20\x73\x65\x65"
  "\x20\x74\x68\x65\x20\x73\x6f\x75\x72\x63\x65\x20\x66\x6f\x72\x20"
  "\x63\x6f\x70\x79\x69\x6e\x67\x20\x63\x6f\x6e\x64\x69\x74\x69\x6f"
  "\x6e\x73\x2e\x20\x20\x54\x68\x65\x72\x65\x20\x69\x73\x20\x4e\x4f"
  "\x0a\x77\x61\x72\x72\x61\x6e\x74\x79\x3b\x20\x6e\x6f\x74\x20\x65"
  "\x76\x65\x6e\x20\x66\x6f\x72\x20\x4d\x45\x52\x43\x48\x41\x4e\x54"
  "\x41\x42\x49\x4c\x49\x54\x59\x20\x6f\x72\x20\x46\x49\x54\x4e\x45"
  "\x53\x53\x20\x46\x4f\x52\x20\x41\x20\x50\x41\x52\x54\x49\x43\x55"
  "\x4c\x41\x52\x20\x50\x55\x52\x50\x4f\x53\x45\x2e\x04\x09\x04\x0a"
  "\x04\x06\x49\x6d\x61\x67\x65\x0d\x64\x69\x73\x6b\x2d\x72\x65\x73"
  "\x74\x6f\x72\x65\x0a\x64\x69\x73\x6b\x2d\x73\x61\x76\x65\x05\x10"
  "\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02"
  "\x03\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07"
  "\x11";

SCHEME_OBJECT *
savres_so_data_84d6ca69f64db586 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_savres_so_data_84d6ca69f64db586 [0]))), (sizeof (prog_savres_so_data_84d6ca69f64db586)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_7]));
}

DECLARE_COMPILED_DATA_NS ("savres.so", savres_so_data_84d6ca69f64db586)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("savres.so", "d3ef62a3dc37f975")
